//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[Sankantsu](-sankantsu.md)

# Sankantsu

[common]\
val [Sankantsu](-sankantsu.md): [Yaku](../-yaku/index.md)

三杠子
